Contributing
============

.. note::

    The
    `Code of Conduct <https://github.com/idom-team/idom/blob/main/CODE_OF_CONDUCT.md>`__
    applies in all community spaces. If you are not familiar with our Code of Conduct
    policy, take a minute to read it before making your first contribution.

The IDOM team welcomes contributions and contributors of all kinds - whether they come
as code changes, participation in the discussions, opening issues and pointing out bugs,
or simply sharing your work with your colleagues and friends. We're excited to see how
you can help move this project and community forward!

.. list-table::
    :header-rows: 1

    *   - I'm Looking For...
        - Description

    *   - `A discussion board <https://github.com/idom-team/idom/discussions>`__
        - Ask questions, share ideas, or show projects

    *   - `Where to report issues <https://github.com/idom-team/idom/issues>`__
        - Tell us about any problems you're having

    *   - :ref:`How to contribute Code <Developer Guide>`
        - Make and review code changes

    *   - `Other related projects <https://github.com/idom-team>`__
        - Find other projects created by the IDOM team


Everyone Can Contribute!
------------------------

Trust us, there's so many ways to support the project. We're always looking for people
who can:

- Improve our documentation
- Teach and tell others about IDOM
- Share ideas for new features
- Report bugs
- Participate in general discussions

Still aren't sure what you have to offer? Just
`ask us <https://github.com/idom-team/idom/discussions>`__ and we'll help you make your
first contribution.
